# eto-mysql-databaselib

# OK SO MOST IMPORTANT THING, IF YOU WANNA USE THIS LIB YOU NEED TO HAVE A MYSQL DATABASE ONLINE,THEN, THE MOST IMPORTANT STUFF TO DO IS THIS:


```py
    databaselib.basemysqldatabaselib.host = "your database host"
    databaselib.basemysqldatabaselib.user = "your database user to acess the database"
    databaselib.basemysqldatabaselib.password = "your database password"
    databaselib.basemysqldatabaselib.db = "the name of your db"
```